summaryrefslogtreecommitdiffstats
path: root/kscd
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:49:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:49:11 -0600
commit83fbc82a101309e171089f0d5ed080f82a367345 (patch)
treec7b61083b6e2d4bfceaace9a7f018181ea36afec /kscd
parentb248983f92b865ef74636ab5a673ae3a88f79c20 (diff)
downloadtdemultimedia-83fbc82a101309e171089f0d5ed080f82a367345.tar.gz
tdemultimedia-83fbc82a101309e171089f0d5ed080f82a367345.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kscd')
-rw-r--r--kscd/ChangeLog2
-rw-r--r--kscd/TODO2
-rw-r--r--kscd/bwlednum.cpp12
-rw-r--r--kscd/bwlednum.h2
-rw-r--r--kscd/cddbdlg.cpp4
-rw-r--r--kscd/configWidget.cpp2
-rw-r--r--kscd/configWidgetUI.ui6
-rw-r--r--kscd/kcompactdisc.cpp26
-rw-r--r--kscd/kcompactdisc.h14
-rw-r--r--kscd/kscd.cpp52
-rw-r--r--kscd/kscd.h4
-rw-r--r--kscd/kscdmagic/README6
-rw-r--r--kscd/kscdmagic/syna.h2
-rw-r--r--kscd/ledlamp.cpp2
-rw-r--r--kscd/ledlamp.h4
-rw-r--r--kscd/libwm/cdtext.c18
-rw-r--r--kscd/libwm/include/wm_cdtext.h2
-rw-r--r--kscd/libwm/plat_news.c4
-rw-r--r--kscd/panel.ui18
19 files changed, 91 insertions, 91 deletions
diff --git a/kscd/ChangeLog b/kscd/ChangeLog
index ab561f86..3cb6493c 100644
--- a/kscd/ChangeLog
+++ b/kscd/ChangeLog
@@ -225,7 +225,7 @@ Fri May 15 18:28:40 1998 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
Tue Apr 14 05:17:36 1998 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
- * tqlayout corrections for kscd magic dialog
+ * layout corrections for kscd magic dialog
Sat Jan 17 21:36:27 1998 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
diff --git a/kscd/TODO b/kscd/TODO
index 2851ae13..e10c01c8 100644
--- a/kscd/TODO
+++ b/kscd/TODO
@@ -6,4 +6,4 @@ AJS:
o fix eject button
o don't show "no disc" error on startup
o direct digital playback
-o better GUI tqlayout for LCD panel
+o better GUI layout for LCD panel
diff --git a/kscd/bwlednum.h b/kscd/bwlednum.h
index 13064f44..6382946d 100644
--- a/kscd/bwlednum.h
+++ b/kscd/bwlednum.h
@@ -68,7 +68,7 @@ private:
bool seg_contained_in( char c, char* seg);
void drawSegment( const TQPoint &, char, TQPainter &, int, bool = FALSE );
- void drawSymbol( TQPainter *p,char s ,bool tqrepaint);
+ void drawSymbol( TQPainter *p,char s ,bool repaint);
char* old_segments;
char* current_segments;
diff --git a/kscd/cddbdlg.cpp b/kscd/cddbdlg.cpp
index fea5ddd6..e3dd02e0 100644
--- a/kscd/cddbdlg.cpp
+++ b/kscd/cddbdlg.cpp
@@ -4,7 +4,7 @@
#include <tqkeycode.h>
#include <tqdatetime.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <tqfile.h>
#include <tqdir.h>
#include <tqfileinfo.h>
@@ -90,7 +90,7 @@ void CDDBDlg::submitFinished(KCDDB::CDDB::Result r)
else
{
TQString str = i18n("Error sending record.\n\n%1")
- .tqarg(KCDDB::CDDB::resultToString(r));
+ .arg(KCDDB::CDDB::resultToString(r));
KMessageBox::error(this, str, i18n("Record Submission"));
}
} // submitFinished()
diff --git a/kscd/configWidget.cpp b/kscd/configWidget.cpp
index 3a1ceff5..5f7652d4 100644
--- a/kscd/configWidget.cpp
+++ b/kscd/configWidget.cpp
@@ -28,7 +28,7 @@
#include <kurlrequester.h>
#include <tqcheckbox.h>
#include <kcombobox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <config.h>
extern "C" {
diff --git a/kscd/configWidgetUI.ui b/kscd/configWidgetUI.ui
index 1477a193..de755edf 100644
--- a/kscd/configWidgetUI.ui
+++ b/kscd/configWidgetUI.ui
@@ -84,7 +84,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>292</width>
<height>20</height>
@@ -221,7 +221,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>171</width>
<height>81</height>
@@ -401,7 +401,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>45</height>
diff --git a/kscd/kcompactdisc.cpp b/kscd/kcompactdisc.cpp
index 83a9c532..c65df07b 100644
--- a/kscd/kcompactdisc.cpp
+++ b/kscd/kcompactdisc.cpp
@@ -81,7 +81,7 @@ extern "C"
#endif
}
-#include <tqtextcodec.h>
+#include <textcodec.h>
#include <fixx11h.h>
// Our internal definition of when we have no disc. Used to guard some
@@ -100,7 +100,7 @@ const unsigned KCompactDisc::missingDisc = (unsigned)-1;
KCompactDisc::KCompactDisc(InformationMode infoMode) :
m_device(TQString()),
m_status(0),
- m_previoustqStatus(123456),
+ m_previousStatus(123456),
m_discId(missingDisc),
m_previousDiscId(0),
m_artist(TQString()),
@@ -143,7 +143,7 @@ unsigned KCompactDisc::discPosition() const
return cur_pos_abs * 1000 - FRAMES_TO_MS(m_trackStartFrames[0]);
}
-TQString KCompactDisc::disctqStatus(int status)
+TQString KCompactDisc::discStatus(int status)
{
TQString message;
@@ -282,7 +282,7 @@ bool KCompactDisc::setDevice(
<< m_device << ", "
<< (digitalPlayback ? audioSystem : TQString()) << ", "
<< (digitalPlayback ? audioDevice : TQString()) << ", status: "
- << disctqStatus(status) << endl;
+ << discStatus(status) << endl;
if (status < 0)
{
@@ -295,7 +295,7 @@ bool KCompactDisc::setDevice(
setVolume(volume);
}
- m_previoustqStatus = m_status = wm_cd_status();
+ m_previousStatus = m_status = wm_cd_status();
if (m_infoMode == Asynchronous)
timerExpired();
@@ -307,7 +307,7 @@ bool KCompactDisc::setDevice(
void KCompactDisc::setVolume(unsigned volume)
{
int status = wm_cd_volume(volume, WM_BALANCE_SYMMETRED);
- kdDebug() << "Volume change: " << volume << ", status: " << disctqStatus(status) << endl;
+ kdDebug() << "Volume change: " << volume << ", status: " << discStatus(status) << endl;
}
void KCompactDisc::stop()
@@ -380,9 +380,9 @@ void KCompactDisc::timerExpired()
if (WM_CDS_NO_DISC(m_status) || (m_device == TQString()))
{
- if (m_previoustqStatus != m_status)
+ if (m_previousStatus != m_status)
{
- m_previoustqStatus = m_status;
+ m_previousStatus = m_status;
m_discId = missingDisc;
m_previousDiscId = 0;
m_trackArtists.clear();
@@ -428,7 +428,7 @@ void KCompactDisc::timerExpired()
else
{
m_trackArtists.append(i18n("Unknown Artist"));
- m_trackTitles.append(i18n("Track %1").tqarg(TQString::number(i).rightJustify(2, '0')));
+ m_trackTitles.append(i18n("Track %1").arg(TQString::number(i).rightJustify(2, '0')));
}
// FIXME: KDE4
// track.length = cd->trk[i - 1].length;
@@ -450,12 +450,12 @@ void KCompactDisc::timerExpired()
}
if (isPlaying())
{
- m_previoustqStatus = m_status;
+ m_previousStatus = m_status;
// Update the current playing position.
emit trackPlaying(m_track, trackPosition());
}
else
- if (m_previoustqStatus != m_status)
+ if (m_previousStatus != m_status)
{
// If we are not playing, then we are either paused, or stopped.
switch (m_status)
@@ -467,7 +467,7 @@ void KCompactDisc::timerExpired()
emit trayOpening();
break;
default:
- if (m_previoustqStatus == WM_CDM_PLAYING || m_previoustqStatus == WM_CDM_PAUSED
+ if (m_previousStatus == WM_CDM_PLAYING || m_previousStatus == WM_CDM_PAUSED
&& m_status == WM_CDM_STOPPED)
{
emit discStopped();
@@ -475,7 +475,7 @@ void KCompactDisc::timerExpired()
break;
}
- m_previoustqStatus = m_status;
+ m_previousStatus = m_status;
}
}
diff --git a/kscd/kcompactdisc.h b/kscd/kcompactdisc.h
index 10d5eabb..8015ab27 100644
--- a/kscd/kcompactdisc.h
+++ b/kscd/kcompactdisc.h
@@ -34,7 +34,7 @@
* @see #discChanged(): A disc was inserted or removed.
* @see #trayOpening(): A disc is being removed.
*
- * The progress of ptqlayout is modelled by these signals:
+ * The progress of playout is modelled by these signals:
*
* @see #trackPlaying(): A track started playing, or is still playing.
* @see #trackPaused(): A track was paused.
@@ -64,12 +64,12 @@ public:
void eject();
/**
- * Start ptqlayout at given position of track.
+ * Start playout at given position of track.
*/
void play(unsigned startTrack = 0, unsigned startTrackPosition = 0, unsigned endTrack = 0);
/**
- * Pause/resume ptqlayout.
+ * Pause/resume playout.
*/
void pause();
@@ -96,7 +96,7 @@ public:
void setVolume(unsigned volume);
/**
- * Stop ptqlayout.
+ * Stop playout.
*/
void stop();
@@ -281,7 +281,7 @@ private:
TQTimer timer;
TQString m_device;
int m_status;
- int m_previoustqStatus;
+ int m_previousStatus;
unsigned m_discId;
unsigned m_previousDiscId;
TQString m_artist;
@@ -292,8 +292,8 @@ private:
TQStringList m_trackTitles;
unsigned m_track;
unsigned m_previousTrack;
- void checkDevicetqStatus();
- TQString disctqStatus(int status);
+ void checkDeviceStatus();
+ TQString discStatus(int status);
class KCompactDiscPrivate *d;
InformationMode m_infoMode;
diff --git a/kscd/kscd.cpp b/kscd/kscd.cpp
index 74842d50..2dbf3c8c 100644
--- a/kscd/kscd.cpp
+++ b/kscd/kscd.cpp
@@ -24,8 +24,8 @@
#include <tqdir.h>
#include <tqregexp.h>
-#include <tqtextstream.h>
-#include <tqlayout.h>
+#include <textstream.h>
+#include <layout.h>
#include <tqhbox.h>
#include <tqvbox.h>
#include <tqapplication.h>
@@ -76,7 +76,7 @@
#include "cddbdlg.h"
#include "configWidget.h"
-#include <tqtextcodec.h>
+#include <textcodec.h>
#include <kcompactdisc.h>
#include <fixx11h.h>
@@ -212,7 +212,7 @@ KSCD::KSCD( TQWidget *parent, const char *name )
setFocusPolicy(TQ_NoFocus);
- songListCB->tqsetSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Fixed);
+ songListCB->setSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Fixed);
adjustSize();
setFixedHeight(this->height());
} // KSCD
@@ -550,7 +550,7 @@ void KSCD::trackChanged(unsigned track, unsigned trackLength)
justTheName = justTheName.right(justTheName.length() - 4);
TQToolTip::remove(songListCB);
- TQToolTip::add(songListCB, i18n("Current track: %1").tqarg(justTheName));
+ TQToolTip::add(songListCB, i18n("Current track: %1").arg(justTheName));
}
timeSlider->blockSignals(true);
timeSlider->setRange(0, trackLength ? trackLength - 1 : 0);
@@ -688,7 +688,7 @@ void KSCD::randomSelected()
{
setShuffle(Prefs::randomPlay()?0:1);
- /* FIXME this helps us to display "Random" in tqStatus line
+ /* FIXME this helps us to display "Random" in Status line
should it maybe to be replaced with symbol "RAND" or something others */
statuslabel->setText(Prefs::randomPlay()?i18n("Random"):i18n("Play"));
} // randomSelected
@@ -800,7 +800,7 @@ void KSCD::setDevicePaths()
{
// This device did not seem usable.
TQString str = i18n("CD-ROM read or access error (or no audio disc in drive).\n"\
- "Please make sure you have access permissions to:\n%1").tqarg(
+ "Please make sure you have access permissions to:\n%1").arg(
KCompactDisc::urlToDevice(Prefs::cdDevice()));
KMessageBox::error(this, str, i18n("Error"));
}
@@ -1211,8 +1211,8 @@ void KSCD::lookupCDDBDone(CDDB::Result result)
CDInfoList::iterator it;
TQStringList list;
for ( it = cddb_info.begin(); it != cddb_info.end(); ++it ) {
- list.append( TQString("%1, %2, %3").tqarg((*it).artist).tqarg((*it).title)
- .tqarg((*it).genre));
+ list.append( TQString("%1, %2, %3").arg((*it).artist).arg((*it).title)
+ .arg((*it).genre));
}
bool ok(false);
@@ -1313,7 +1313,7 @@ int KSCD::currentPosition()
return m_cd->trackPosition();
}
-int KSCD::gettqStatus()
+int KSCD::getStatus()
{
if (m_cd->isPlaying())
return 2;
@@ -1419,62 +1419,62 @@ void KSCD::information(int i)
{
case 0:
str = TQString("http://musicmoz.org/cgi-bin/ext.cgi?artist=%1")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 1:
str = TQString("http://ubl.artistdirect.com/cgi-bin/gx.cgi/AppLogic+Search?select=MusicArtist&searchstr=%1&searchtype=NormalSearch")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 2:
str = TQString("http://www.cduniverse.com/cgi-bin/cdubin.exe/rlinka/ean=%1")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 3:
str = TQString("http://www.alltheweb.com/search?cat=web&q=%1")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 4:
str = TQString("http://altavista.com/web/results?q=%1&kgs=0&kls=1&avkw=xytx")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 5:
str = TQString("http://msxml.excite.com/_1_2UDOUB70SVHVHR__info.xcite/dog/results?otmpl=dog/webresults.htm&qkw=%1&qcat=web&qk=20&top=1&start=&ver=14060")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 6:
str = TQString("http://www.google.com/search?q=%1")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 7:
str = TQString("http://groups.google.com/groups?oi=djq&as_q=%1&num=20")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 8:
str = TQString("http://www.hotbot.com/default.asp?prov=Inktomi&query=%1&ps=&loc=searchbox&tab=web")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 9:
str = TQString("http://search.lycos.com/default.asp?lpv=1&loc=searchhp&tab=web&query=%1")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 10:
str = TQString("http://search.dmoz.org/cgi-bin/search?search=%1")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
case 11:
str = TQString("http://search.yahoo.com/bin/search?p=%1")
- .tqarg(encodedArtist);
+ .arg(encodedArtist);
break;
default:
@@ -1563,13 +1563,13 @@ TQStringList KSCD::trackList()
return tracks;
}
-void KSCD::populateSongList(TQString infotqStatus)
+void KSCD::populateSongList(TQString infoStatus)
{
// set the artist and title labels as well as the dock tooltip.
- if (!infotqStatus.isEmpty())
- artistlabel->setText(infotqStatus);
+ if (!infoStatus.isEmpty())
+ artistlabel->setText(infoStatus);
else
- artistlabel->setText(TQString("%1 - %2").tqarg(cddbInfo.artist, cddbInfo.title));
+ artistlabel->setText(TQString("%1 - %2").arg(cddbInfo.artist, cddbInfo.title));
songListCB->clear();
for (unsigned i = 0; i < cddbInfo.trackInfoList.count(); i++)
diff --git a/kscd/kscd.h b/kscd/kscd.h
index a6c192bd..9a4e1044 100644
--- a/kscd/kscd.h
+++ b/kscd/kscd.h
@@ -102,7 +102,7 @@ k_dcop:
int currentTrack();
int currentTrackLength();
int currentPosition();
- int gettqStatus();
+ int getStatus();
TQString currentTrackTitle();
TQString currentAlbum();
TQString currentArtist();
@@ -175,7 +175,7 @@ protected:
void calculateDisplayedTime();
void calculateDisplayedTime(int sec);
void setSongListTo(int whichTrack);
- void populateSongList(TQString infotqStatus);
+ void populateSongList(TQString infoStatus);
void updatePlayPB(bool playing);
void updateConfigDialog(configWidget* widget);
diff --git a/kscd/kscdmagic/README b/kscd/kscdmagic/README
index b2366190..64af4f6f 100644
--- a/kscd/kscdmagic/README
+++ b/kscd/kscdmagic/README
@@ -15,14 +15,14 @@ Introduction
This is a program for representing sounds visually from a CD or line
input or piped from another program. It goes beyond the usual oscilliscope
style program by combining an FFT and stereo positioning information to
-give a two dimensional display. Some of the tqshapes I have observed are:
+give a two dimensional display. Some of the shapes I have observed are:
* Drums: clouds of color, fairly high
* Clean guitar: several horizontal lines, low down
* Rough guitar: a cloud, low down
* Trumpet: Lots of horizontal lines everywhere
* Flute: A single horizontal line, low down
* Voice: A vertical line with some internal structure
- * Synthesizer: All kinds of weird tqshapes!
+ * Synthesizer: All kinds of weird shapes!
Synaesthesia can run in a window in X or full screen using SVGAlib.
@@ -139,7 +139,7 @@ Changes
Support for SDL.
2.0 - Bug fixes: Fixed problem in xlib.c that caused occasional segfaults,
several endianness problems fixed.
- New effects: Wave, heat, diamond tqshaped points.
+ New effects: Wave, heat, diamond shaped points.
Piping sound now longer requires the twiddle factor.
Yet another interface redesign.
Partial support for LinuxPPC (pipe mode only)
diff --git a/kscd/kscdmagic/syna.h b/kscd/kscdmagic/syna.h
index 4d35e3e0..d359a8c2 100644
--- a/kscd/kscdmagic/syna.h
+++ b/kscd/kscdmagic/syna.h
@@ -160,7 +160,7 @@ enum SoundSource { SourceLine, SourceCD, SourcePipe };
void cdOpen(char *cdromName);
void cdClose(void);
-void cdGettqStatus(int &track, int &frames, SymbolID &state);
+void cdGetStatus(int &track, int &frames, SymbolID &state);
void cdPlay(int trackFrame, int endFrame=-1);
void cdStop(void);
void cdPause(void);
diff --git a/kscd/ledlamp.cpp b/kscd/ledlamp.cpp
index 96675921..b9edef18 100644
--- a/kscd/ledlamp.cpp
+++ b/kscd/ledlamp.cpp
@@ -20,7 +20,7 @@
#include <stdio.h>
#include <tqpainter.h>
-#include <tqbrush.h>
+#include <brush.h>
#include <tqpen.h>
#include <tqcolor.h>
#include "ledlamp.h"
diff --git a/kscd/ledlamp.h b/kscd/ledlamp.h
index 6bd2e44f..f6ba4915 100644
--- a/kscd/ledlamp.h
+++ b/kscd/ledlamp.h
@@ -42,10 +42,10 @@ public:
State state() const { return s; }
- void setState(State state) { s= state; tqrepaint(false); }
+ void setState(State state) { s= state; repaint(false); }
- void toggleState() { if (s == On) s= Off; else if (s == Off) s= On; tqrepaint(false); }
+ void toggleState() { if (s == On) s= Off; else if (s == Off) s= On; repaint(false); }
public slots:
void toggle() { toggleState(); };
void on() { setState(On); };
diff --git a/kscd/libwm/cdtext.c b/kscd/libwm/cdtext.c
index fafd039f..bb4e19b8 100644
--- a/kscd/libwm/cdtext.c
+++ b/kscd/libwm/cdtext.c
@@ -21,8 +21,8 @@
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
-#ifdef libtqunicode
- #include <tqunicode.h>
+#ifdef libunicode
+ #include <unicode.h>
#endif
#include "include/wm_config.h"
@@ -155,12 +155,12 @@ void get_data_from_cdtext_pack(
int arr = pack->header_field_id2_tracknumber;
int i;
int language_block;
- int tqunicode;
+ int unicode;
language_block = (pack->header_field_id4_block_no >> 4) & 0x07;
- tqunicode = pack->header_field_id4_block_no & 0x80;
+ unicode = pack->header_field_id4_block_no & 0x80;
- if(!tqunicode)
+ if(!unicode)
{
for(i = 0; i < DATAFIELD_LENGHT_IN_PACK; i++)
{
@@ -180,7 +180,7 @@ void get_data_from_cdtext_pack(
}
}
}
-#ifdef libtqunicode
+#ifdef libunicode
else /* doublebytes ;-) */
{
for(i = 0; i < DATAFIELD_LENGHT_IN_PACK; i += 2)
@@ -203,7 +203,7 @@ void get_data_from_cdtext_pack(
}
#else
else {
- wm_lib_message(WM_MSG_LEVEL_ERROR | WM_MSG_CLASS, "can't handle tqunicode");
+ wm_lib_message(WM_MSG_LEVEL_ERROR | WM_MSG_CLASS, "can't handle unicode");
}
#endif
}
@@ -315,9 +315,9 @@ get_glob_cdtext(struct wm_drive *d, int redo)
{
wm_cdtext_info.blocks[j] = lp_block;
wm_cdtext_info.blocks[j]->block_code = code;
- wm_cdtext_info.blocks[j]->block_tqunicode = pack->header_field_id4_block_no & 0x80;
+ wm_cdtext_info.blocks[j]->block_unicode = pack->header_field_id4_block_no & 0x80;
wm_lib_message(WM_MSG_LEVEL_DEBUG | WM_MSG_CLASS,
- "CDTEXT INFO: created a new language block; code %i, %s characters\n", code, lp_block->block_tqunicode?"doublebyte":"singlebyte");
+ "CDTEXT INFO: created a new language block; code %i, %s characters\n", code, lp_block->block_unicode?"doublebyte":"singlebyte");
/*
unsigned char block_encoding; not jet!
cdtext_string* block_encoding_text;
diff --git a/kscd/libwm/include/wm_cdtext.h b/kscd/libwm/include/wm_cdtext.h
index ba481be0..e843ee95 100644
--- a/kscd/libwm/include/wm_cdtext.h
+++ b/kscd/libwm/include/wm_cdtext.h
@@ -44,7 +44,7 @@ typedef unsigned char cdtext_string[MAX_LENGHT_OF_CDTEXT_STRING];
struct cdtext_info_block {
/* management */
unsigned char block_code;
- unsigned char block_tqunicode; /* 0 - single chars, 1 - doublebytes */
+ unsigned char block_unicode; /* 0 - single chars, 1 - doublebytes */
unsigned char block_encoding; /* orange book -? */
cdtext_string* block_encoding_text;
diff --git a/kscd/libwm/plat_news.c b/kscd/libwm/plat_news.c
index 304ebfda..4b9f2ef7 100644
--- a/kscd/libwm/plat_news.c
+++ b/kscd/libwm/plat_news.c
@@ -181,7 +181,7 @@ int
gen_get_drive_status( struct wm_drive *d, int oldmode,
int *mode, int *pos, int *track, int *index)
{
- struct CD_tqStatus sc;
+ struct CD_Status sc;
/* If we can't get status, the CD is ejected, so default to that. */
*mode = WM_CDM_EJECTED;
@@ -199,7 +199,7 @@ gen_get_drive_status( struct wm_drive *d, int oldmode,
}
/* Disc is ejected. Close the device. */
- if (CD_GettqStatus(d->fd, &sc))
+ if (CD_GetStatus(d->fd, &sc))
{
gen_close(d);
return (0);
diff --git a/kscd/panel.ui b/kscd/panel.ui
index 43fd739a..2ef615ef 100644
--- a/kscd/panel.ui
+++ b/kscd/panel.ui
@@ -27,7 +27,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout8</cstring>
+ <cstring>layout8</cstring>
</property>
<vbox>
<property name="name">
@@ -40,7 +40,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<hbox>
<property name="name">
@@ -92,7 +92,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -128,7 +128,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout7</cstring>
+ <cstring>layout7</cstring>
</property>
<grid>
<property name="name">
@@ -160,7 +160,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>270</width>
<height>80</height>
@@ -203,7 +203,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<grid>
<property name="name">
@@ -221,7 +221,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>100</width>
<height>35</height>
@@ -239,7 +239,7 @@
<cstring>statuslabel</cstring>
</property>
<property name="text">
- <string>tqStatus</string>
+ <string>Status</string>
</property>
</widget>
<widget class="TQLabel" row="1" column="2">
@@ -275,7 +275,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>0</height>
diff --git a/kscd/bwlednum.cpp b/kscd/bwlednum.cpp
index 385c0c74..eb18917e 100644
--- a/kscd/bwlednum.cpp
+++ b/kscd/bwlednum.cpp
@@ -84,7 +84,7 @@ void BW_LED_Number::setLEDColor( const TQColor& fgColor, const TQColor& bgColor
fgcolor = fgColor;
bgcolor = bgColor;
- TQColorGroup old_cg = this->tqcolorGroup();
+ TQColorGroup old_cg = this->colorGroup();
TQColorGroup new_cg( fgColor, bgColor,
@@ -168,9 +168,9 @@ void BW_LED_Number::setSmallLED(bool a_boolean){
}
-void BW_LED_Number::drawSymbol( TQPainter *p,char ,bool tqrepaint ){
+void BW_LED_Number::drawSymbol( TQPainter *p,char ,bool repaint ){
- // printf("drawSymbol tqrepaint = %d\n",tqrepaint);
+ // printf("drawSymbol repaint = %d\n",repaint);
TQPoint pos;
@@ -194,7 +194,7 @@ void BW_LED_Number::drawSymbol( TQPainter *p,char ,bool tqrepaint ){
pos = TQPoint( Xoffset , Yoffset );
- if(tqrepaint){
+ if(repaint){
// this draw the non-illumintated segments
@@ -222,7 +222,7 @@ void BW_LED_Number::drawSymbol( TQPainter *p,char ,bool tqrepaint ){
}
}
}
- else{ // we are not repainting ourselves due to a tqrepaint event but rather
+ else{ // we are not repainting ourselves due to a repaint event but rather
// genuinely changing the symbol that is to be displayed
for(int l = 0; l <= NUM_OF_SEGMENTS -1; l++){
@@ -277,7 +277,7 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
TQPoint pt = pos;
- TQColorGroup g = tqcolorGroup();
+ TQColorGroup g = colorGroup();
TQColor lightColor,darkColor;
if ( erase ){